/*
 * Copyright (C) 2006  Emmanuel VARAGNAT <>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/param.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <assert.h>
#include <getopt.h>

#include "common.h"
#include "fat.h"
#include "version.h"

static char *destdir = NULL;
static char *filename = NULL;

static int flags = 0;

void usage() {
  printf("Usage: " GEPJ_PROGNAME " [--destdir=<path>] [--dry-run] <image file|block device>\n"
	 " " GEPJ_PROGNAME " version " GEPJ_VERSION "\n"
	 " JPEG file retriever for FAT16 filesystem\n"
	 "\n");
}

void parse_cmdline(int argc, char *argv[]) {
  int c;

  while (1) {
    int option_index = 0;
    static struct option long_options[] = {
      {"destdir",     required_argument, NULL, 10},
      {"dry-run",     no_argument      , NULL, 20},
      {0, 0, 0, 0}
    };
    
    c = getopt_long (argc, argv, "",
		     long_options, &option_index);
    if (c == -1)
      break;
    
    switch (c) {
    case 10:
      destdir = optarg;
      break;
    case 20:
      flags |= FLAGS_DRY_RUN;
      break;
    }
  }

  if (optind < argc)
    filename = argv[optind];

  if(destdir == NULL) {
    usage(argv[0]);
    fprintf(stderr, "Too few arguments !\n");
    exit(10);
  }

  
}

int main(int argc, char* argv[]) {
  /* self tests */
  /*
  assert(sizeof(struct common_boot_sector) == 36);
  assert(sizeof(struct fat12_boot_sector) == SECTOR_SIZE - 36);
  assert(sizeof(struct fat32_boot_sector) == SECTOR_SIZE - 36);
  assert(sizeof(struct boot_sector) == SECTOR_SIZE);
  */

  parse_cmdline(argc, argv);

  if( strlen(destdir) > MAXPATHLEN ) {
    fprintf(stderr, "Pathname too long\n");
    exit(1);
  }    
  
  recover_photos(filename, destdir, flags);

  return 0;
}
